@@ -5,11 +5,11 @@ from dataclasses import asdict, is_dataclass
 class Laozi:
     @staticmethod
     def parse_final(obj):
-        return obj 
+        return obj
 
     @classmethod
     def parse_str(cls, obj, prefix=''):
-        obj = self.parse_final(obj)
+        obj = cls.parse_final(obj)
         if not prefix:
             yield f'"{obj}"'
         else:
@@ -17,7 +17,7 @@ class Laozi:
 
     @classmethod
     def parse_int(cls, obj, prefix=''):
-        obj = self.parse_final(obj)
+        obj = cls.parse_final(obj)
         yield f'{prefix[:-1]}={obj}'
 
     @classmethod
